==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/aispeech/AIServiceSpeechAsync.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.aispeech;

import com.oracle.bmc.aispeech.requests.*;
import com.oracle.bmc.aispeech.responses.*;

/**
 * The OCI Speech Service harnesses the power of spoken language by allowing developers to easily
 * convert file-based data containing human speech into highly accurate text transcriptions.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220101")
public interface AIServiceSpeechAsync extends AutoCloseable {

    /** Rebuilds the client from scratch. Useful to refresh certificates. */
    void refreshClient();

    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     *
     * @param endpoint The endpoint of the serice.
     */
    void setEndpoint(String endpoint);

    /** Gets the set endpoint for REST call (ex, https://www.example.com) */
    String getEndpoint();

    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     *
     * <p>Note, this will call {@link #setEndpoint(String) setEndpoint} after resolving the
     * endpoint. If the service is not available in this region, however, an
     * IllegalArgumentException will be raised.
     *
     * @param region The region of the service.
     */
    void setRegion(com.oracle.bmc.Region region);

    /**
     * Sets the region to call (ex, 'us-phoenix-1').
     *
     * <p>Note, this will first try to map the region ID to a known Region and call {@link
     * #setRegion(Region) setRegion}.
     *
     * <p>If no known Region could be determined, it will create an endpoint based on the default
     * endpoint format ({@link com.oracle.bmc.Region#formatDefaultRegionEndpoint(Service, String)}
     * and then call {@link #setEndpoint(String) setEndpoint}.
     *
     * @param regionId The public region ID.
     */
    void setRegion(String regionId);

    /**
     * Determines whether realm specific endpoint should be used or not. Set
     * realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm
     * specific endpoint template, otherwise set it to "false"
     *
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint
     *     template
     */
    void useRealmSpecificEndpointTemplate(boolean realmSpecificEndpointTemplateEnabled);

    /**
     * Canceling the job cancels all the tasks under it.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CancelTranscriptionJobResponse> cancelTranscriptionJob(
            CancelTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CancelTranscriptionJobRequest, CancelTranscriptionJobResponse>
                    handler);

    /**
     * Cancel Transcription Task
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CancelTranscriptionTaskResponse> cancelTranscriptionTask(
            CancelTranscriptionTaskRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CancelTranscriptionTaskRequest, CancelTranscriptionTaskResponse>
                    handler);

    /**
     * Moves a transcription Job resource into a different compartment.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ChangeTranscriptionJobCompartmentResponse>
            changeTranscriptionJobCompartment(
                    ChangeTranscriptionJobCompartmentRequest request,
                    com.oracle.bmc.responses.AsyncHandler<
                                    ChangeTranscriptionJobCompartmentRequest,
                                    ChangeTranscriptionJobCompartmentResponse>
                            handler);

    /**
     * Creates a new Transcription Job.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CreateTranscriptionJobResponse> createTranscriptionJob(
            CreateTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CreateTranscriptionJobRequest, CreateTranscriptionJobResponse>
                    handler);

    /**
     * Delete API cleans job, tasks and the related metadata. However the generated transcriptions
     * in customer tenancy will not be deleted.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<DeleteTranscriptionJobResponse> deleteTranscriptionJob(
            DeleteTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            DeleteTranscriptionJobRequest, DeleteTranscriptionJobResponse>
                    handler);

    /**
     * Gets a Transcription Job by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<GetTranscriptionJobResponse> getTranscriptionJob(
            GetTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetTranscriptionJobRequest, GetTranscriptionJobResponse>
                    handler);

    /**
     * Gets a Transcription Task by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<GetTranscriptionTaskResponse> getTranscriptionTask(
            GetTranscriptionTaskRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetTranscriptionTaskRequest, GetTranscriptionTaskResponse>
                    handler);

    /**
     * Returns a list of Transcription Jobs.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ListTranscriptionJobsResponse> listTranscriptionJobs(
            ListTranscriptionJobsRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListTranscriptionJobsRequest, ListTranscriptionJobsResponse>
                    handler);

    /**
     * Returns a list of Transcription Tasks.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ListTranscriptionTasksResponse> listTranscriptionTasks(
            ListTranscriptionTasksRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListTranscriptionTasksRequest, ListTranscriptionTasksResponse>
                    handler);

    /**
     * Updates the Transcription Job
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<UpdateTranscriptionJobResponse> updateTranscriptionJob(
            UpdateTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            UpdateTranscriptionJobRequest, UpdateTranscriptionJobResponse>
                    handler);
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/aispeech/AIServiceSpeechAsync.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.aispeech;

import com.oracle.bmc.aispeech.requests.*;
import com.oracle.bmc.aispeech.responses.*;

/**
 * The OCI Speech Service harnesses the power of spoken language by allowing developers to easily
 * convert file-based data containing human speech into highly accurate text transcriptions.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220101")
public interface AIServiceSpeechAsync extends AutoCloseable {

    /** Rebuilds the client from scratch. Useful to refresh certificates. */
    void refreshClient();

    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     *
     * @param endpoint The endpoint of the serice.
     */
    void setEndpoint(String endpoint);

    /** Gets the set endpoint for REST call (ex, https://www.example.com) */
    String getEndpoint();

    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     *
     * <p>Note, this will call {@link #setEndpoint(String) setEndpoint} after resolving the
     * endpoint. If the service is not available in this region, however, an
     * IllegalArgumentException will be raised.
     *
     * @param region The region of the service.
     */
    void setRegion(com.oracle.bmc.Region region);

    /**
     * Sets the region to call (ex, 'us-phoenix-1').
     *
     * <p>Note, this will first try to map the region ID to a known Region and call {@link
     * #setRegion(Region) setRegion}.
     *
     * <p>If no known Region could be determined, it will create an endpoint based on the default
     * endpoint format ({@link com.oracle.bmc.Region#formatDefaultRegionEndpoint(Service, String)}
     * and then call {@link #setEndpoint(String) setEndpoint}.
     *
     * @param regionId The public region ID.
     */
    void setRegion(String regionId);

    /**
     * Determines whether realm specific endpoint should be used or not. Set
     * realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm
     * specific endpoint template, otherwise set it to "false"
     *
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint
     *     template
     */
    void useRealmSpecificEndpointTemplate(boolean realmSpecificEndpointTemplateEnabled);

    /**
     * Canceling the job cancels all the tasks under it.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CancelTranscriptionJobResponse> cancelTranscriptionJob(
            CancelTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CancelTranscriptionJobRequest, CancelTranscriptionJobResponse>
                    handler);

    /**
     * Cancel Transcription Task
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CancelTranscriptionTaskResponse> cancelTranscriptionTask(
            CancelTranscriptionTaskRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CancelTranscriptionTaskRequest, CancelTranscriptionTaskResponse>
                    handler);

    /**
     * Moves a Customization resource into a different compartment.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ChangeCustomizationCompartmentResponse>
            changeCustomizationCompartment(
                    ChangeCustomizationCompartmentRequest request,
                    com.oracle.bmc.responses.AsyncHandler<
                                    ChangeCustomizationCompartmentRequest,
                                    ChangeCustomizationCompartmentResponse>
                            handler);

    /**
     * Moves a transcription Job resource into a different compartment.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ChangeTranscriptionJobCompartmentResponse>
            changeTranscriptionJobCompartment(
                    ChangeTranscriptionJobCompartmentRequest request,
                    com.oracle.bmc.responses.AsyncHandler<
                                    ChangeTranscriptionJobCompartmentRequest,
                                    ChangeTranscriptionJobCompartmentResponse>
                            handler);

    /**
     * Creates a new Customization.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CreateCustomizationResponse> createCustomization(
            CreateCustomizationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CreateCustomizationRequest, CreateCustomizationResponse>
                    handler);

    /**
     * Returns an authentication token to the user.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CreateRealtimeSessionTokenResponse> createRealtimeSessionToken(
            CreateRealtimeSessionTokenRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CreateRealtimeSessionTokenRequest, CreateRealtimeSessionTokenResponse>
                    handler);

    /**
     * Creates a new Transcription Job.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<CreateTranscriptionJobResponse> createTranscriptionJob(
            CreateTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            CreateTranscriptionJobRequest, CreateTranscriptionJobResponse>
                    handler);

    /**
     * Delete Customization and its metadata from tenancy.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<DeleteCustomizationResponse> deleteCustomization(
            DeleteCustomizationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            DeleteCustomizationRequest, DeleteCustomizationResponse>
                    handler);

    /**
     * Delete API cleans job, tasks and the related metadata. However the generated transcriptions
     * in customer tenancy will not be deleted.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<DeleteTranscriptionJobResponse> deleteTranscriptionJob(
            DeleteTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            DeleteTranscriptionJobRequest, DeleteTranscriptionJobResponse>
                    handler);

    /**
     * Gets a Customization by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<GetCustomizationResponse> getCustomization(
            GetCustomizationRequest request,
            com.oracle.bmc.responses.AsyncHandler<GetCustomizationRequest, GetCustomizationResponse>
                    handler);

    /**
     * Gets a Transcription Job by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<GetTranscriptionJobResponse> getTranscriptionJob(
            GetTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetTranscriptionJobRequest, GetTranscriptionJobResponse>
                    handler);

    /**
     * Gets a Transcription Task by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<GetTranscriptionTaskResponse> getTranscriptionTask(
            GetTranscriptionTaskRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetTranscriptionTaskRequest, GetTranscriptionTaskResponse>
                    handler);

    /**
     * Returns a list of Customizations.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ListCustomizationsResponse> listCustomizations(
            ListCustomizationsRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListCustomizationsRequest, ListCustomizationsResponse>
                    handler);

    /**
     * Returns a list of Transcription Jobs.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ListTranscriptionJobsResponse> listTranscriptionJobs(
            ListTranscriptionJobsRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListTranscriptionJobsRequest, ListTranscriptionJobsResponse>
                    handler);

    /**
     * Returns a list of Transcription Tasks.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<ListTranscriptionTasksResponse> listTranscriptionTasks(
            ListTranscriptionTasksRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListTranscriptionTasksRequest, ListTranscriptionTasksResponse>
                    handler);

    /**
     * Updates a Customization by identifier
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<UpdateCustomizationResponse> updateCustomization(
            UpdateCustomizationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            UpdateCustomizationRequest, UpdateCustomizationResponse>
                    handler);

    /**
     * Updates the Transcription Job
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was provided. Note,
     *     if you provide an AsyncHandler and use the Future, some types of responses (like
     *     java.io.InputStream) may not be able to be read in both places as the underlying stream
     *     may only be consumed once.
     */
    java.util.concurrent.Future<UpdateTranscriptionJobResponse> updateTranscriptionJob(
            UpdateTranscriptionJobRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            UpdateTranscriptionJobRequest, UpdateTranscriptionJobResponse>
                    handler);
}
